@@ -4,7 +4,7 @@ import time
 """
 initialize some basics
 """
-def init():
+def Rinit():
     rand = Random()
     rand.seed()
     return rand
