@@ -1,8 +1,10 @@
-from .Rrandom import Random, init
+from .Rrandom import Rinit, Random
 from .Rmath import Math
 from .Rrequests import Request
 from .Rsugaku import Sugaku
 from .Rusty import Rusty
 from .Rusty import Webhook
 from .Rusty import Rplus
-from .Rcolor import Back
\ No newline at end of file
+from .Rcolor import Back
+
+__all__ = ['Random', 'init', 'Math', 'Request', 'Sugaku', 'Rusty', 'Webhook', 'Rplus', 'Back']
